@@ -18,29 +18,29 @@ class init_anim:
 
     Arguments:
     ----------
-        :param t: :class:`~np.ndarray', contains the time information that corresponds with the six degrees of freedom data 
-        :param speed_up: float, the "real time speed up" or the ratio of the duration of the data to the duration of the animation 
-        :param scale: float, global physical scale factor of the animation, i.e., .1 will reduce everything to be 1/10th its original size
+        :param: `t` :type: `np.ndarray`, contains the time information that corresponds with the six degrees of freedom data 
+        :param: `speed_up` :type: `float`, the "real time speed up" or the ratio of the duration of the data to the duration of the animation 
+        :param: ` scale` :type: `float`, global physical scale factor of the animation, i.e., .1 will reduce everything to be 1/10th its original size
     """
     def __init__(self, t, speed_up, scale):
 
         self.frame_rate = bpy.context.scene.render.fps
-        """float: frame rate of animation"""
+        """:type: `float`: frame rate of animation"""
         
         self.t = t
-        """:class:`~np.ndarray': contains the time information that corresponds with the six degrees of freedom data"""
+        """:type: `np.ndarray`: contains the time information that corresponds with the six degrees of freedom data"""
         
         self.speed_up = speed_up
-        """float: the "real time speed up" or the ratio of the duration of the data to the duration of the animation"""
+        """:type: `float`: the "real time speed up" or the ratio of the duration of the data to the duration of the animation"""
         
         self.frames = np.linspace(1, int(t[-1]*self.frame_rate/speed_up+1), len(t)).astype(int)
-        """:class:`~np.ndarray': the frames that Blender will animate and have corresponding data for"""
+        """:type: `np.ndarray`: the frames that Blender will animate and have corresponding data for"""
         
         self.frame_duration = self.frames[-1]
-        """int: number of total frames in animation"""
+        """:type: `int`: number of total frames in animation"""
 
         self.scale = scale
-        """float: global physical scale factor of the animation, i.e., .1 will reduce everything to be 1/10th its original size"""
+        """:type: `float`: global physical scale factor of the animation, i.e., .1 will reduce everything to be 1/10th its original size"""
         
         bpy.context.scene.frame_start = 1
         bpy.context.scene.frame_end = self.frame_duration+1
@@ -53,9 +53,9 @@ class ref_frame:
 
 
     Arguments:
-        :param name: str, the Blender object name of the reference frame
-        :param parent: :class:`~bpy.data.object', the Blender object parent of this reference frame 
-        :param anim: :class:`~bpsci.core.init_anim`), class object that was used to initialize the animation
+        :param: `name` :type: `str`, the Blender object name of the reference frame
+        :param: `parent` :type: `bpy.data.object`, the Blender object parent of this reference frame 
+        :param: `anim` :class:`bpsci.core.init_anim`, class object that was used to initialize the animation
     
     Attributes:
     -----------
@@ -65,13 +65,13 @@ class ref_frame:
         
         
         self.name = name
-        """str: the Blender object name of the reference frame"""
+        """:type: `str`: the Blender object name of the reference frame"""
         self.parent = parent
-        """:class:`~bpy.data.object': the Blender object parent of this reference frame"""
+        """:type: `bpy.data.object`: the Blender object parent of this reference frame"""
         
         # Blender portion
         self.ob = bpy.data.objects.new(name, None)
-        """:class:`~bpy.data.object': the Blender object that represents this reference frame"""
+        """:type: `bpy.data.object`: the Blender object that represents this reference frame"""
         
         bpy.context.scene.collection.objects.link(self.ob)
         
@@ -80,10 +80,10 @@ class ref_frame:
         self.ob.rotation_mode = 'QUATERNION'
 
         self.frames = anim.frames
-        """:class:`~np.ndarray': the frames that Blender will animate and have corresponding data for"""
+        """:type: `np.ndarray`: the frames that Blender will animate and have corresponding data for"""
 
         self.scale = anim.scale
-        """float: global physical scale factor of the animation"""
+        """:type: `float`: global physical scale factor of the animation"""
 
         
     def static_6DOF(self, quat, x, y, z):
@@ -99,10 +99,10 @@ class ref_frame:
 
         Arguments:
         ----------
-            :param quat: :class:`~np.ndarray', an numpy array of one quaternion
-            :param x: float, the x position 
-            :param y: float, the y position 
-            :param z: float, the z position 
+            :param: `quat` :type: `np.ndarray`, an numpy array of one quaternion
+            :param: `x` :type: `float`, the x position 
+            :param: `y` :type: `float`, the y position 
+            :param: `z` :type: `float`, the z position 
 
         """
         if not(quat is None):
@@ -128,10 +128,10 @@ class ref_frame:
 
         Arguments:
         ----------
-            :param quat: :class:`~np.ndarray', an numpy array of quaternions over time
-            :param x: :class:`~np.ndarray', the x position over time
-            :param y: :class:`~np.ndarray', the y position over time
-            :param z: :class:`~np.ndarray', the z position over time
+            :param: `quat` :type: `np.ndarray`, an numpy array of quaternions over time
+            :param: `x` :type: `np.ndarray`, the x position over time
+            :param: `y` :type: `np.ndarray`, the y position over time
+            :param: `z` :type: `np.ndarray`, the z position over time
 
         """
 
@@ -167,32 +167,32 @@ class dyn_obj:
 
     Arguments:
     ----------
-        :param obj: :class:`~bpy.data.object', the Blender object that will be animated
-        :param pa: :class:`~np.ndarray', the offset of the principal axes specified by the :param euler_type:
-        :param euler_type: str. the Euler angle order (i.e. 'xyz' for 1,2,3 or 'zxz' for 3,1,3)
-        :param parent: :class:`~bpy.data.object', the Blender object parent of the original object 
-        :param anim: :class:`~bpsci.core.init_anim`, class object that was used to initialize the animation
+        :param: `obj: :type` `bpy.data.object`, the Blender object that will be animated
+        :param: `pa: :type` `np.ndarray`, the offset of the principal axes specified by the :param: ` euler_type:
+        :param: `euler_type` :type: `str`. the Euler angle order (i.e. 'xyz' for 1,2,3 or 'zxz' for 3,1,3)
+        :param: `parent` :type: `bpy.data.object`, the Blender object parent of the original object 
+        :param: `anim` :class: `bpsci.core.init_anim`, class object that was used to initialize the animation
 
     """
     def __init__(self, obj, pa, euler_type, parent, anim):
         
 
         self.parent = parent
-        """:class:`~bpy.data.object': the Blender object parent of this reference frame"""
+        """:type: `bpy.data.object`: the Blender object parent of this reference frame"""
 
         self.frames = anim.frames
-        """:class:`~np.ndarray': the frames that Blender will animate and have corresponding data for"""
+        """:type: `np.ndarray`: the frames that Blender will animate and have corresponding data for"""
         self.scale = anim.scale
-        """float: global physical scale factor of the animation"""
+        """:type: `float`: global physical scale factor of the animation"""
 
         self.ob = obj
-        """:class:`~bpy.data.object': the Blender object that will be animated"""
+        """:type: `bpy.data.object`: the Blender object that will be animated"""
         
         self.euler_pa = pa
-        """:class:`~np.ndarray': the offset of the principal axes specified by the :param euler_type:"""
+        """:type: `np.ndarray`: the offset of the principal axes specified by the :param: ` euler_type:"""
         
         self.quat = R.from_euler(euler_type, pa).as_quat()
-        """:class:`~np.ndarray': a numpy array of one quaternion that represents the principal axes offset"""
+        """:type: `np.ndarray`: a numpy array of one quaternion that represents the principal axes offset"""
         
         self.non_rot = ref_frame(obj.name+'_non_rot', parent, anim)
         """:class:`~bpsci.core.ref_frame`: the non-rotational reference frame (owner of translational movement only)"""
@@ -211,7 +211,7 @@ class dyn_obj:
         self.body.static_6DOF(-self.quat, None, None, None)
 
         self.name = obj.name
-        """str: the Blender object name of the original object"""
+        """:type: `str`: the Blender object name of the original object"""
 
     def apply_animation(self, x_list, y_list, z_list, quat_list):
 
@@ -219,10 +219,10 @@ class dyn_obj:
         Animates a :class:`~bpsci.core.dyn_obj` in the full six degrees of freedom
 
         Arguments:
-            :param x_list: :class:`~np.ndarray', a numpy array of the x position over time
-            :param y_list: :class:`~np.ndarray', a numpy array of the y position over time
-            :param z_list: :class:`~np.ndarray'. a numpy array of the z position over time
-            :param quat_list: :class:`~np.ndarray' or None, a numpy array of the rotational quaternion over time. Can be passed None if rotation is ignored.
+            :param: `x_list` :type: `np.ndarray`, a numpy array of the x position over time
+            :param: `y_list` :type: `np.ndarray`, a numpy array of the y position over time
+            :param: `z_list` :type: `np.ndarray`. a numpy array of the z position over time
+            :param: `quat_list` :type: `np.ndarray` or None, a numpy array of the rotational quaternion over time. Can be passed None if rotation is ignored.
             """
 
         self.pa_axes.dynamic_6DOF(quat_list, None, None, None)
@@ -234,10 +234,10 @@ class dyn_obj:
 
         Arguments:
         ----------
-            :param staticity (str): a string (either 'static' or 'dynamic') that specifies whether the the streamline is animated over time
-            :param int_x: :class:`~np.ndarray', a numpy array of the x position over time
-            :param int_y: :class:`~np.ndarray', a numpy array of the y position over time
-            :param int_z: :class:`~np.ndarray', a numpy array of the z position over time
+            :param: `staticity` :type: `str`, a string (either 'static' or 'dynamic') that specifies whether the the streamline is animated over time
+            :param: `int_x` :type: `np.ndarray`, a numpy array of the x position over time
+            :param: `int_y` :type: `np.ndarray`, a numpy array of the y position over time
+            :param: `int_z` :type: `np.ndarray`, a numpy array of the z position over time
         
         Attributes:
         -----------
@@ -245,9 +245,9 @@ class dyn_obj:
 
 
         name = self.name+'_streamline'
-        """str: the Blender object name of the streamline"""
+        """:type: `str`, the Blender object name of the streamline"""
         frames = self.frames
-        """:class:`~np.ndarray': the frames that Blender will animate and have corresponding data for"""
+        """:type: `np.ndarray`: the frames that Blender will animate and have corresponding data for"""
         
         int_size = len(int_x)
         int_coords = np.zeros((int_size, 3))
@@ -292,12 +292,12 @@ class dyn_vec:
 
     Arguments:
     ----------
-        :param parent: :class:`~bpy.data.object', the Blender object the vector is associated with
-        :param name: str, the Blender object name of the vector ('_vector' will be appended to this name)
-        :param scale_mag: float, the scaling factor of the vector's magnitude axis (purely aesthetic)
-        :param scale_off: float, the scaling factor of the vector's off-axes (purely aesthetic)
-        :param offset: tuple[float], offset of vector from the parent object (purely aesthetic)
-        :param anim: :class:`~bpsci.core.init_anim`, class object that was used to initialize the animation
+        :param: `parent` :type: `bpy.data.object`, the Blender object the vector is associated with
+        :param: `name` :type: `str`, the Blender object name of the vector ('_vector' will be appended to this name)
+        :param: `scale_mag` :type: `float`, the scaling factor of the vector's magnitude axis (purely aesthetic)
+        :param: `scale_off` :type: `float`, the scaling factor of the vector's off-axes (purely aesthetic)
+        :param: `offset` :type: `tuple`, offset of vector from the parent object (purely aesthetic)
+        :param: `anim` :class:`bpsci.core.init_anim`, class object that was used to initialize the animation
 
     """
     def __init__(self, parent, name, scale_mag, scale_off, offset, anim):
@@ -305,22 +305,22 @@ class dyn_vec:
         
 
         self.parent = parent
-        """:class:`~bpy.data.object': the Blender object parent of this reference frame"""
+        """:type: `bpy.data.object`: the Blender object parent of this reference frame"""
 
         self.name = name+"_vector"
         """str: the Blender object name of the vector"""
         
         self.parent_rf = ref_frame(self.name+"_empty", self.parent, anim)
-        """:class:`~bpy.data.object': holds the vector"""
+        """:type: `bpy.data.object`: holds the vector"""
 
         self.filepath = self.filepath = __file__.replace("__init__.py", "").replace("\\core.py", "")+'\\assets\\objects\\arrow.obj' #"C:/Users/vargh/Documents/GitHub/bpsci/bpsci/assets/objects/arrow.obj" #bpsci.__file__.replace("__init__.py", "")+'\\assets\\objects\\arrow.obj'
-        """str: file path to arrow asset"""
+        """:type: `str`: file path to arrow asset"""
 
 
         vec = bpy.ops.import_scene.obj(filepath=self.filepath)
         vec = bpy.context.selected_objects[0]
         self.vec = vec
-        """:class:`~bpy.data.object': the actual arrow asset"""
+        """:type: `bpy.data.object`: the actual arrow asset"""
         
         self.parent_rf.ob.location = offset
         vec.parent = self.parent_rf.ob
@@ -329,19 +329,19 @@ class dyn_vec:
         self.scale = scale_mag
         vec.scale = (scale_mag, scale_off, scale_off)
         self.anim = anim
-        """:class:`~bpsci.core.init_anim`: class object that was used to initialize the animation"""
+        """:class:`bpsci.core.init_anim`: class object that was used to initialize the animation"""
         
         self.frames = anim.frames
-        """:class:`~np.ndarray': the frames that Blender will animate and have corresponding data for"""
+        """:type: `np.ndarray`: the frames that Blender will animate and have corresponding data for"""
     def animate(self, x, y, z):
         """
         Animates a dynamic vector
 
         Arguments:
         ----------
-            :param x: :class:`~np.ndarray', a numpy array of the x component over time
-            :param y: :class:`~np.ndarray',  a numpy array of the y component over time
-            :param z: :class:`~np.ndarray', a numpy array of the z component over time
+            :param: `x` :type: `np.ndarray`, a numpy array of the x component over time
+            :param: `y` :type: `np.ndarray`,  a numpy array of the y component over time
+            :param: `z` :type: `np.ndarray`, a numpy array of the z component over time
 
         Attributes:
         -----------
@@ -365,7 +365,7 @@ class dyn_vec:
         norm_z = z/max_z *self.scale
         
         self.point_rf = ref_frame(self.name+"_pointing_empty", self.parent, self.anim)
-        """:class:`~bpy.data.object': an empty that provides calculates the directionality of the vector"""
+        """:type: `bpy.data.object`: an empty that provides calculates the directionality of the vector"""
         
         tracking_constraint = self.parent_rf.ob.constraints.new('DAMPED_TRACK')
         tracking_constraint.target = self.point_rf.ob
@@ -392,13 +392,13 @@ class anim_text:
 
     Arguments:
     ----------
-        :param name: str, the Blender object name of the text ('_text' will be appended to this name)
-        :param parent: :class:`~bpy.data.object', the Blender object parent of this text 
-        :param anim: :class:`~bpsci.core.init_anim`, class object that was used to initialize the animation
-        :param data: :class:`~np.ndarray', the data to be displayed (same length as the number of animated frames)
-        :param label: str, a label to append to the text (if no label is desired, pass '')
-        :param fix_place: int, the number of decimal places to fix the text to
-        :param if_str: bool, whether or not the data is a numerical or string vector. Currently only numerical vectors are supported.
+        :param: `name` :type: `str`, the Blender object name of the text ('_text' will be appended to this name)
+        :param: `parent` :type: `bpy.data.object`, the Blender object parent of this text 
+        :param: `anim` :class:`bpsci.core.init_anim`, class object that was used to initialize the animation
+        :param: `data` :type: `np.ndarray`, the data to be displayed (same length as the number of animated frames)
+        :param: `label` :type: `str`, a label to append to the text (if no label is desired, pass '')
+        :param: `fix_place` int, the number of decimal places to fix the text to
+        :param: `if_str` bool, whether or not the data is a numerical or string vector. Currently only numerical vectors are supported.
 
     """
     def __init__(self, name, parent, anim, data, label, fix_place, if_str):
